@@ -55,7 +55,8 @@ def pytest_collection_modifyitems(config, items):
         skip_reason = "needs an approval directory configured to run."
     skip_missing_dataset = pytest.mark.skip(reason=skip_reason)
     for item in items:
-        if "approval_test_geo_data_root" in item.fixturenames and (approval_root is None or not approval_root.exists()):
+        if "approval_test_geo_data_root" in getattr(item, 'fixturenames', {}) and \
+                (approval_root is None or not approval_root.exists()):
             item.add_marker(skip_missing_dataset)
 
 
@@ -135,7 +136,7 @@ def verify_raster_as_geo_tif(verify_geo_tif, tmp_path_factory):
                    *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
                    options: Optional[GeoOptions] = None):
         tile_file = tmp_path_factory.mktemp("raster_as_geo_tif") / "raster.tif"
-        tile.rio.to_raster(tile_file)
+        options.tif_writer(tile_file, tile)
         verify_geo_tif(tile_file, options=options)
 
     return _verify_fn
